@@ -11,6 +11,8 @@ sub Mojo::Webqq::Client::_get_vfwebqq {
     my $headers = {
         Referer => 'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',
         json    => 1,
+        ua_request_timeout => 10,
+        ua_retry_times => 3,
     };
     
     my $json = $self->http_get($self->gen_url($api_url,@query_string),$headers);
