@@ -10,7 +10,12 @@ sub Mojo::Webqq::Model::_get_group_info {
         t       =>  time(),
     ); 
 
-    my $headers = {Referer => 'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',json=>1};
+    my $headers = {
+        Referer => 'http://s.web2.qq.com/proxy.html?v=20130916001&callback=1&id=1',
+        json=>1,
+        ua_request_timeout => $self->model_update_timeout,
+        ua_retry_times => 3,
+    };
     my $is_blocking = ref $callback eq "CODE"?0:1;
     my $handle = sub {
         my $json = shift;
