@@ -16,11 +16,20 @@ sub call{
     my $data = shift;
     $client->die("请先安装模块 Mojo::IRC::Server::Chinese") if not $Mojo::Webqq::Plugin::IRCShell::has_mojo_irc_server;
     my $master_irc_nick = $data->{master_irc_nick};
-    my $upload_api = $data->{upload_api} // 'https://sm.ms/api/upload';
+    my $upload_api = $data->{upload_api}; #'http://img.vim-cn.com/';
     my $is_load_friend = defined $data->{load_friend}?$data->{load_friend}:0;
-    my @groups = ref($data->{allow_group}) eq "ARRAY"?@{$data->{allow_group}}:();
     my %mode = ref($data->{mode}) eq "HASH"?%{$data->{mode}}:();
-    $ircd = Mojo::IRC::Server::Chinese->new(listen=>$data->{listen},log=>$client->log);
+    $data->{auto_join_channel} = 1 if not defined $data->{auto_join_channel};
+    $data->{create_chanserv_user} = 1 if not defined $data->{create_chanserv_user};
+    $ircd = Mojo::IRC::Server::Chinese->new(listen=>$data->{listen},log=>$client->log,auth=>$data->{auth});
+    if($data->{create_chanserv_user}){
+        my $chanserv= $ircd->new_user(id=>"__ChanServ__",name=>"ChanServ:虚拟用户",user=>"__ChanServ__",nick=>"ChanServ",virtual=>1);
+        $ircd->on(new_channel=>sub{
+            my ($ircd,$channel) = @_;
+            return if index( $channel->mode ,"v" ) == -1;
+            $chanserv->join_channel($channel) if not $chanserv->is_join_channel($channel);
+        });
+    }
     $ircd->on(privmsg=>sub{
         my($ircd,$user,$msg) = @_;
         if(substr($msg->{params}[0],0,1) eq "#" ){
@@ -64,7 +73,7 @@ sub call{
             if(not defined $u){
                 my $friend = $client->search_friend(displayname=>$nick);
                 return if not defined $friend;
-                my $channel = $ircd->search_channel(name=>'#我的好友') || $ircd->new_channel(name=>'#我的好友',mode=>"Pis");
+                my $channel = $ircd->search_channel(name=>'#我的好友') || $ircd->new_channel(name=>'#我的好友',mode=>"Pivs");
                 return if not defined $channel;
                 $u = $ircd->new_user(
                     id      =>$friend->id,
@@ -107,8 +116,9 @@ sub call{
 
     my $callback = sub{
         my %delete_channel  = map {$_->id => $_} grep {$_->name ne "#我的好友"}  $ircd->channels;
+        #$ircd->remove_user($_) for grep {$_->id ne '__ChanServ__' and $_->is_virtual} $ircd->users;
         $ircd->remove_user($_) for grep {$_->is_virtual} $ircd->users;
-        my $friend_channel = $ircd->new_channel(name=>'#我的好友',mode=>"Pis");
+        my $friend_channel = $ircd->new_channel(name=>'#我的好友',mode=>"Pivs");
         if($is_load_friend){
             $client->each_friend(sub{
                 my($client,$friend) = @_;
@@ -139,8 +149,10 @@ sub call{
         }
         $client->each_group(sub{
             my($client,$group) = @_;
-            return if(@groups and not first {$group->name eq $_} @groups);
-            my $mode = defined $mode{$group->name}?$mode{$group->name}:"Pi";
+            return if ref $data->{ban_group}  eq "ARRAY" and first {$_=~/^\d+$/?$group->uid eq $_:$group->name eq $_} @{$data->{ban_group}};
+            return if ref $data->{allow_group}  eq "ARRAY" and !first {$_=~/^\d+$/?$group->uid eq $_:$group->name eq $_} @{$data->{allow_group}};
+            my $mode = defined $mode{$group->name}?$mode{$group->name}."":"Piv";
+            $mode .= "v" if index($mode,"v")==-1;
             my $channel_name = '#'.$group->name;$channel_name=~s/\s|,|&//g;
             my $channel = $ircd->search_channel(name=>$channel_name);
             if(defined $channel){
@@ -154,21 +166,23 @@ sub call{
     };
     $client->on(new_group=>sub{
         my($client,$group) = @_;
-        return if(@groups and not first {$group->displayname eq $_} @groups);
-        my $mode = defined $mode{$group->displayname}?$mode{$group->displayname}:"Pi";
-        my $channel_name = '#'.$group->displayname;$channel_name=~s/\s|,|&//g;
+        return if ref $data->{ban_group}  eq "ARRAY" and first {$_=~/^\d+$/?$group->uid eq $_:$group->name eq $_} @{$data->{ban_group}};
+        return if ref $data->{allow_group}  eq "ARRAY" and !first {$_=~/^\d+$/?$group->uid eq $_:$group->name eq $_} @{$data->{allow_group}};
+        my $mode = defined $mode{$group->name}?$mode{$group->name}:"Piv";
+        $mode .= "v" if index($mode,"v")==-1;
+        my $channel_name = '#'.$group->name;$channel_name=~s/\s|,|&//g;
         my $channel = $ircd->search_channel(name=>$channel_name);
         if(defined $channel){
             $channel->id($group->id);
             $channel->remove_user($_) for grep {$_->is_virtual} $channel->users;
         }
-        else{ $ircd->new_channel(id=>$group->id,name=>'#'.$group->displayname,mode=>$mode);}
+        else{ $ircd->new_channel(id=>$group->id,name=>'#'.$group->name,mode=>$mode);}
     });
     $client->on(lose_group=>sub{
         my($client,$group) = @_;
-        return if(@groups and not first {$group->displayname eq $_} @groups);
-        my $mode = defined $mode{$group->displayname}?$mode{$group->displayname}:"Pi";
-        my $channel_name = '#'.$group->displayname;$channel_name=~s/\s|,|&//g;
+        return if ref $data->{ban_group}  eq "ARRAY" and first {$_=~/^\d+$/?$group->uid eq $_:$group->name eq $_} @{$data->{ban_group}};
+        return if ref $data->{allow_group}  eq "ARRAY" and !first {$_=~/^\d+$/?$group->uid eq $_:$group->name eq $_} @{$data->{allow_group}};
+        my $channel_name = '#'.$group->name;$channel_name=~s/\s|,|&//g;
         my $channel = $ircd->search_channel(name=>$channel_name);
         $ircd->remove_channel($channel) if defined $channel;
     });
@@ -182,7 +196,7 @@ sub call{
         if($msg->type eq "friend_message"){
             my $friend = $msg->sender;
             my $user = $ircd->search_user(id=>$friend->id,virtual=>1) || $ircd->search_user(nick=>$friend->displayname,virtual=>0);
-            my $channel = $ircd->search_channel(name=>'#我的好友') || $ircd->new_channel(name=>'#我的好友',mode=>"Pis");
+            my $channel = $ircd->search_channel(name=>'#我的好友') || $ircd->new_channel(name=>'#我的好友',mode=>"Pivs");
             return if not defined $channel;
             if(not defined $user){
                 $user = $ircd->new_user(
@@ -207,7 +221,8 @@ sub call{
 
         if($msg->type eq "sess_message"){
             my $member  = $msg->sender;
-            return if @groups and not first {$member->group->name eq $_} @groups;
+            return if ref $data->{ban_group}  eq "ARRAY" and first {$_=~/^\d+$/?$member->group->uid eq $_:$member->group->name eq $_} @{$data->{ban_group}};
+            return if ref $data->{allow_group}  eq "ARRAY" and !first {$_=~/^\d+$/?$member->group->uid eq $_:$member->group->name eq $_} @{$data->{allow_group}};
             return if $msg->via ne "group";
             my $user = $ircd->search_user(id=>$member->id,virtual=>1) || $ircd->search_user(nick=>$member->displayname,virtual=>0);
             my $channel = $ircd->search_channel(id=>$member->group->id) ||
@@ -241,7 +256,8 @@ sub call{
 
         elsif($msg->type eq "group_message"){
             my $member = $msg->sender;
-            return if @groups and not first {$member->group->name eq $_} @groups;
+            return if ref $data->{ban_group}  eq "ARRAY" and first {$_=~/^\d+$/?$member->group->uid eq $_:$member->group->name eq $_} @{$data->{ban_group}};
+            return if ref $data->{allow_group}  eq "ARRAY" and !first {$_=~/^\d+$/?$member->group->uid eq $_:$member->group->name eq $_} @{$data->{allow_group}};
             my $user = $ircd->search_user(id=>$member->id,virtual=>1) || $ircd->search_user(nick=>$member->displayname,virtual=>0);
             my $channel = $ircd->search_channel(id=>$member->group->id) ||
                     $ircd->new_channel(id=>$member->group->id,name=>'#'.$member->group->name,);
@@ -263,6 +279,15 @@ sub call{
             else{
                 $user->join_channel($channel) if not $user->is_join_channel($channel);
             }
+
+            #master用户如果没有加入到该频道就自动加入，防止漏收消息
+            if($data->{auto_join_channel}){
+                for(grep {$_->nick eq $master_irc_nick or $_->is_localhost}
+                    grep {!$_->is_virtual} $ircd->users){
+                    $_->join_channel($channel) if not $_->is_join_channel($channel);
+                }
+            }
+
             for(grep {!$_->is_virtual} $channel->users){
                 my @content = split /\r?\n/,$msg->content;
                 if($content[0]=~/^\@([^\s]+?) /){
@@ -281,11 +306,11 @@ sub call{
     });
     $client->on(send_message=>sub{
         my($client,$msg) = @_;
-        return if $msg->msg_from eq "irc";
+        return if $msg->from eq "irc";
         if($msg->type eq "friend_message"){
             my $friend = $msg->receiver;
             my $user = $ircd->search_user(id=>$friend->id,virtual=>1) || $ircd->search_user(nick=>$friend->displayname,virtual=>0);
-            my $channel = $ircd->search_channel(name=>'#我的好友') || $ircd->new_channel(name=>'#我的好友',mode=>"Pis");
+            my $channel = $ircd->search_channel(name=>'#我的好友') || $ircd->new_channel(name=>'#我的好友',mode=>"Pivs");
             if(not defined $user){
                 $user=$ircd->new_user(
                     id      =>$friend->id,
@@ -313,8 +338,9 @@ sub call{
 
         if($msg->type eq "sess_message"){
             my $member  = $msg->receiver;
-            return if @groups and not first {$member->group->name eq $_} @groups;
             return if $msg->via ne "group";
+            return if ref $data->{ban_group}  eq "ARRAY" and first {$_=~/^\d+$/?$member->group->uid eq $_:$member->group->name eq $_} @{$data->{ban_group}};
+            return if ref $data->{allow_group}  eq "ARRAY" and !first {$_=~/^\d+$/?$member->group->uid eq $_:$member->group->name eq $_} @{$data->{allow_group}};
             my $user = $ircd->search_user(id=>$member->id,virtual=>1)||$ircd->search_user(nick=>$member->displayname,virtual=>0);
             my $channel = $ircd->search_channel(id=>$member->group->id) ||
                     $ircd->new_channel(id=>$member->id,name=>'#'.$member->group->name,);
@@ -344,9 +370,19 @@ sub call{
         }
 
         elsif($msg->type eq "group_message"){
-            return if @groups and not first {$msg->group->name eq $_} @groups;
+            return if ref $data->{ban_group}  eq "ARRAY" and first {$_=~/^\d+$/?$msg->group->uid eq $_:$msg->group->name eq $_} @{$data->{ban_group}};
+            return if ref $data->{allow_group}  eq "ARRAY" and !first {$_=~/^\d+$/?$msg->group->uid eq $_:$msg->group->name eq $_} @{$data->{allow_group}};
             my $channel = $ircd->search_channel(id=>$msg->group->id);
             return unless defined $channel;
+
+            #master用户如果没有加入到该频道就自动加入，防止漏收消息
+            if($data->{auto_join_channel}){
+                for(grep {$_->nick eq $master_irc_nick or $_->is_localhost}
+                    grep {!$_->is_virtual} $ircd->users){
+                    $_->join_channel($channel) if not $_->is_join_channel($channel);
+                }
+            }
+
             for my $master_irc_client (
                 grep {$_->nick eq $master_irc_nick or $_->is_localhost}
                 grep {!$_->is_virtual} $ircd->users
@@ -375,17 +411,13 @@ sub call{
             return unless defined $user;
             return unless defined $channel;
             return unless $user->is_join_channel($channel);
-            $client->http_post($upload_api,{json=>1},form=>{format=>'json',smfile=>{file=>$file_path}},sub{
-                my($json,$ua,$tx)=@_;
-                if(not defined $json){
+            $client->http_post($upload_api,form=>{image=>{file=>$file_path}},sub{
+                my($url,$ua,$tx)=@_;
+                if(not defined $url or $url!~/https?:\/\//){
                     $client->warn("二维码图片上传云存储失败: 响应数据异常");
                     return;
                 }
-                elsif(defined $json and $json->{code} ne 'success' ){
-                    $client->warn("二维码图片上传云存储失败: " . $json->{msg});
-                    return;
-                }
-                $channel->broadcast($user->ident,"PRIVMSG",$channel->name,"图片链接: $json->{data}{url}");
+                $channel->broadcast($user->ident,"PRIVMSG",$channel->name,"图片链接: $url");
             });  
         });
         
@@ -393,22 +425,18 @@ sub call{
             my($client,$file_path,$sender) = @_;
             my $user = $ircd->search_user(id=>$sender->id,virtual=>1)||$ircd->search_user(nick=>$sender->displayname,virtual=>0);
             return unless defined $user;
-            $client->http_post($upload_api,{json=>1},form=>{format=>'json',smfile=>{file=>$file_path}},sub{
-                my($json,$ua,$tx)=@_;
-                if(not defined $json){
+            $client->http_post($upload_api,form=>{image=>{file=>$file_path}},sub{
+                my($url,$ua,$tx)=@_;
+                if(not defined $url or $url!~/https?:\/\//){
                     $client->warn("二维码图片上传云存储失败: 响应数据异常");
                     return;
                 }
-                elsif(defined $json and $json->{code} ne 'success' ){
-                    $client->warn("二维码图片上传云存储失败: " . $json->{msg});
-                    return;
-                }
                 for(
                     grep {$_->nick eq $master_irc_nick or $_->is_localhost}
                     grep {!$_->is_virtual } $ircd->users
                 ){
-                    $_->send($user->ident,"PRIVMSG",$_->nick,"图片链接: $json->{data}{url}");
-                    $user->send($user->ident,"PRIVMSG",$_->nick,"图片链接: $json->{data}{url}");
+                    $_->send($user->ident,"PRIVMSG",$_->nick,"图片链接: $url");
+                    $user->send($user->ident,"PRIVMSG",$_->nick,"图片链接: $url");
                 }
             });
         });
@@ -418,22 +446,18 @@ sub call{
             return if not $sender->is_group_member;
             my $user = $ircd->search_user(id=>$sender->id,virtual=>1)||$ircd->search_user(nick=>$sender->displayname,virtual=>0);
             return unless defined $user;
-            $client->http_post($upload_api,{json=>1},form=>{format=>'json',smfile=>{file=>$file_path}},sub{
-                my($json,$ua,$tx)=@_;
-                if(not defined $json){
+            $client->http_post($upload_api,form=>{image=>{file=>$file_path}},sub{
+                my($url,$ua,$tx)=@_;
+                if(not defined $url or $url!~/https?:\/\//){
                     $client->warn("二维码图片上传云存储失败: 响应数据异常");
                     return;
                 }
-                elsif(defined $json and $json->{code} ne 'success' ){
-                    $client->warn("二维码图片上传云存储失败: " . $json->{msg});
-                    return;
-                }
                 for(
                     grep {$_->nick eq $master_irc_nick or $_->is_localhost}
                     grep {!$_->is_virtual } $ircd->users
                 ){
-                    $_->send($user->ident,"PRIVMSG",$_->nick,"图片链接: $json->{data}{url}");
-                    $user->send($user->ident,"PRIVMSG",$_->nick,"图片链接: $json->{data}{url}");
+                    $_->send($user->ident,"PRIVMSG",$_->nick,"图片链接: $url");
+                    $user->send($user->ident,"PRIVMSG",$_->nick,"图片链接: $url");
                 }
             });
         });
@@ -446,13 +470,17 @@ sub call{
             return if $property ne "nick" and $property ne "markname";
             my $user = $ircd->search_user(id=>$object->id,virtual=>1);
             return unless defined $user;
-            $user->set_nick($object->displayname) if $object->displayname ne $user->nick;
+            my $displayname = $object->displayname;
+            $displayname=~s/\s|\@|!//g;
+            $user->set_nick($displayname) if $displayname ne $user->nick;
         }
         elsif($object->is_group_member){
             return if $property ne "nick" and $property ne "card"; 
             my $user = $ircd->search_user(id=>$object->id,virtual=>1);
             return unless defined $user;
-            $user->set_nick($object->displayname) if $object->displayname ne $user->nick;
+            my $displayname = $object->displayname;
+            $displayname=~s/\s|\@|!//g;
+            $user->set_nick($displayname) if $displayname ne $user->nick;
         }
         elsif($object->is_group){
             return if $property ne "name";
